#############
API reference
#############


.. automodule:: coloc_sat
    :members: generate_coloc, era5_meta, hy2_meta, smos_meta, smap_meta, sar_meta, windsat_meta, intersection

    .. autoclass:: GenerateColoc
        :members:

    .. autoclass:: GetEra5Meta
        :members:

    .. autoclass:: GetHy2Meta
        :members:

    .. autoclass:: GetSmosMeta
        :members:

    .. autoclass:: GetSmapMeta
        :members:

    .. autoclass:: GetSarMeta
        :members:

    .. autoclass:: GetWindSatMeta
        :members:

    .. autoclass:: ProductIntersection
        :members:
